<?php

/**
 * Abonner un auteur
 *
 * @plugin     Abonnements
 * @copyright  2014
 * @author     cedric
 * @licence    GNU/GPL
 * @package    SPIP\Abos\API
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Distribuer une offre d'abonnement, c'est à dire créer un abonnement
 * @param $id_abonnements_offre
 * @param $detail
 * @param $commande
 * @return bool|string
 */
function distribuer_abonnements_offre_dist($id_abonnements_offre, $detail, $commande) {

	// Si on a pas encore envoye cet abonnement, c'est la premiere echeance
	if ($detail['statut'] == 'attente') {
		spip_log("distribuer_abonnements_offre_dist: creation d'un abonnement offre #$id_abonnements_offre pour commande #".$commande['id_commande'], 'abonnements' . _LOG_DEBUG);
		if (!empty($commande['bank_uid'])) {
			$bank_uid = $commande['bank_uid'];
		} else {
			$transaction = sql_fetsel('*', 'spip_transactions', 'statut=' . sql_quote('ok') . ' AND id_commande=' . intval($commande['id_commande']), '', 'id_transaction', '0,1');
			if ($transaction and !empty($transaction['abo_uid'])) {
				$bank_uid = $transaction['abo_uid'];
			}
			elseif (!empty($transaction['id_transaction'])) {
				$bank_uid = $transaction['id_transaction'];
			}
		}

		// c'est une création initiale d'abonnement
		$forcer_creation = true;

		// On crée ou renouvelle
		include_spip('inc/abonnements');
		include_spip('action/editer_abonnement');
		$options = [
			'id_commande' => $commande['id_commande'],
			'forcer_creation' => $forcer_creation,
			'bank_uid' => $bank_uid,
			'mode_paiement' => $commande['mode'],
			'prix_ht_initial' => $detail['prix_unitaire_ht'], // reprendre le prix qui a ete enregistre dans la commande
		];

		if (isset($commande['echeances_date_debut']) and intval($commande['echeances_date_debut'])) {
			$options['date_debut'] = $commande['echeances_date_debut'];
		}

		if ($retour = abonnement_creer_ou_renouveler($commande['id_auteur'], $id_abonnements_offre, $options)) {
			return 'envoye';
		}

	}
	// si on vient de 'attente_echeance' c'est un renouvellement
	elseif (!empty($commande['statut_ancien']) and $commande['statut_ancien'] === 'attente_echeance') {
		$forcer_creation = false;
		spip_log("distribuer_abonnements_offre_dist: renouvellement d'un abonnement offre #$id_abonnements_offre pour commande #".$commande['id_commande'], 'abonnements' . _LOG_DEBUG);

		// On crée ou renouvelle
		include_spip('inc/abonnements');
		include_spip('action/editer_abonnement');
		$options = [
			'id_commande' => $commande['id_commande'],
			'forcer_creation' => $forcer_creation,
			'mode_paiement' => $commande['mode'],
			'prix_ht_echeance' => $detail['prix_unitaire_ht'], // reprendre le prix qui a ete enregistre dans la commande
			'raison' => 'Paiement échéance',
		];
		if (!empty($commande['bank_uid'])) {
			$options['bank_uid'] = $commande['bank_uid'];
		}

		if ($retour = abonnement_creer_ou_renouveler($commande['id_auteur'], $id_abonnements_offre, $options)) {
			return 'envoye';
		}
	}

	return false;
}